@@ -4,14 +4,14 @@ CREATE TABLE meta
 	key   varchar(255) primary key,
 	value varchar(255)
 );
-INSERT INTO meta (key, value) VALUES ('version', '0.2.3');
+INSERT INTO meta (key, value) VALUES ('version', '0.2.10');
 
 CREATE TABLE messages
 (
 	message_id  varchar(255) primary key,
 	destination varchar(255) not null,
 	persistent  char(1) default '1' not null,
-	in_use_by   int,
+	in_use_by   varchar(255),
 	body        text,
 	timestamp   decimal(15,5),
 	size        int,
